﻿# coding UTF-8
__author__ = 'svan'

from xml.etree.ElementTree import ElementTree
from optparse import OptionParser
from parser import ParserError
import sys

def options_error(msg):
            raise ParserError('OptionParser failed: %s' % msg)
colors = {1:'Black', 2:'Red', 3:'Yellow', 4:'Pink', 5:'Green', 6:'Orange', 7:'Purple',
    8:'Blue', 9:'Beige', 10:'Brown',  12:'Teal', 13:'Navy', 14:'Maroon', 15:'LimeGreen'}

def getLinkOrNothing(r, n):
    a = r.find(n)
    if a is not None:
        txt = a.text if a.text else ''
        return '[url={0}]Читать[/url]'.format(txt)
    return str()

def getAuthorOrNothing(r, n):
    a = r.find(n)
    if a is not None:
        txt = a.text.encode('UTF-8') if a.text else ''
        return '[url=http://forum.poehali.net/index.php?board=7;action=profile;user={0}]{0}[/url]'.format(txt)
    return str()

def getOrNothing(r, n):
    a = r.find(n)
    if a is not None:
        txt = a.text.encode('UTF-8') if a.text else ''
        return txt
    return str()

def region_to_str(region, index = 2 ):
    getColorName = lambda i: colors[i] if 1 <= i <= 16 else 'Black'
    out = "[b][size={2}][color={1}]{0}[/color][/size][/b]\n".format(region.attrib['name'].encode('UTF-8'), getColorName(index), index)
    report_str = str()
    first = True
    for report in region.findall('report'):
        if first:
            first = False
            report_str = "[table][tr][td]Автор[/td][td]Заголовок[/td][td]Дата[/td][td]Маршрут[/td][td]Километраж[/td][td]Дни[/td][td]Ссылка[/td][/tr]\n"
        report_str += "[tr][td]{0}[/td][td]{1}[/td][td]{2}[/td][td]{3}[/td][td]{4}[/td][td]{5}[/td][td]{6}[/td][/tr]\n".format(
            getAuthorOrNothing(report, 'author'),
            getOrNothing(report,'title'),
            getOrNothing(report,'date'),
            getOrNothing(report,'route'),
            getOrNothing(report,'distance'),
            getOrNothing(report,'days'),
            getLinkOrNothing(report,'link')
        )
    out += report_str
    if not first:
        out += "[/table]"
    elif not region.findall('region'):
        out += "\n"
    for sub_region in region.findall('region'):
        out += region_to_str(sub_region, index + 1)
    return out

def main():
    try:
        parser = OptionParser(version='table generator')
        parser.error = options_error
        parser.add_option("-i", "--input_file", dest="input_file", help="Input xml file")
        parser.add_option("-o", "--output_file", dest="output_file", help="Input xml file")
        (options,_) = parser.parse_args()

        if not options.input_file or not options.output_file:
            raise ParserError("You must specify connection string for Customer db")

        tree = ElementTree()
        tree.parse(options.input_file)
        out = str()
        for region in tree.findall('region'):
            out += region_to_str(region, 1)
        print(out)
        tree.write(options.output_file, encoding='UTF-8')
    except Exception as inst:
        print('Fatal error:' + repr(inst))
        return -1

if __name__ == '__main__':
    sys.exit(main())
  